@@ -52,6 +52,10 @@ class ChannelBase(object):
 
     placeholder
         The initial text in the autocomplete text input.
+    
+    static_list
+        A list of static files which are necessary for this channel. It is an
+        empty list by default.
     """
 
     model = None
@@ -61,6 +65,7 @@ class ChannelBase(object):
     placeholder = _(u'type some text to search in this autocomplete')
     result_template = None
     autocomplete_template = None
+    static_list = []
 
     def __init__(self):
         """
@@ -78,6 +83,8 @@ class ChannelBase(object):
                 'autocomplete_light/autocomplete.html',
             ]
 
+        self.request = None
+
     def get_absolute_url(self):
         """
         Return the absolute url for this channel, using
