@@ -19,10 +19,13 @@ static_list
 
 import os.path
 
+from django.db import models
+
 from .channel import ChannelBase
 
 __all__ = ('ChannelRegistry', 'registry', 'register', 'autodiscover', 'static_list')
 
+static_list = []
 
 class ChannelRegistry(dict):
     """
@@ -39,6 +42,24 @@ class ChannelRegistry(dict):
         except KeyError:
             return
 
+    def unregister(self, arg):
+        """
+        Unregister a channel or the channel for a model. Return True on
+        success.
+
+        arg
+            May be a model, or channel class.
+        """
+        if issubclass(arg, models.Model):
+            if arg in self._models.keys():
+                del self._models[arg]
+                return True
+        else:
+            for key, value in self._models.items():
+                if value == arg:
+                    del self._models[key]
+                    return True
+
     def register(self, model, channel=None):
         """
         Add a model to the registry, optionnaly with a given channel class.
@@ -65,6 +86,10 @@ class ChannelRegistry(dict):
         elif channel.model is None:
             channel = type('%sChannel' % model.__name__, (channel,), {'model': model})
 
+        for path in getattr(channel, 'static_list', []):
+            if path not in static_list:
+                static_list.append(path)
+
         self[channel.__name__] = channel
         self._models[channel.model] = channel
 
@@ -80,10 +105,12 @@ def _autodiscover(registry):
         mod = import_module(app)
         # check if the app has static/appname/autocomplete_light.js
         css_path = 'static/%s/autocomplete_light.css' % mod.__name__
-        if os.path.exists(os.path.join(mod.__path__[0], css_path)):
+        if os.path.exists(os.path.join(mod.__path__[0], css_path)) and \
+            css_path[7:] not in static_list:
             static_list.append(css_path[7:])
         js_path = 'static/%s/autocomplete_light.js' % mod.__name__
-        if os.path.exists(os.path.join(mod.__path__[0], js_path)):
+        if os.path.exists(os.path.join(mod.__path__[0], js_path)) and \
+            js_path[7:] not in static_list:
             static_list.append(js_path[7:])
 
         # Attempt to import the app's admin module.
@@ -103,7 +130,6 @@ def _autodiscover(registry):
             if module_has_submodule(mod, 'autocomplete_light_registry'):
                 raise
 
-static_list = []
 registry = ChannelRegistry()
 
 
